---
outputs:
    ComputeEnvironmentArn:
        Description:
            The ARN of the compute environment
        Value: {Ref: ComputeEnvironment}

    PriorityJobQueueArn:
        Description:
            The ARN of the priority job queue
        Value: {Ref: PriorityJobQueue}

    DefaultJobQueueArn:
        Description:
            The ARN of the default job queue
        Value: {Ref: DefaultJobQueue}

    InstanceRole:
        Description:
            The ARN of the instances role 
        Value: {Ref: InstanceRole}
